@@ -9,13 +9,15 @@ import plone.app.iterate
 
 @onsetup
 def setup_products():
+    """ install ilrt.formalworkflow and any dodgy packages
+        that may break Plone if present but not installed
+    """
     fiveconfigure.debug_mode = True
     zcml.load_config('configure.zcml',
                      ilrt.formalworkflow)
     fiveconfigure.debug_mode = False    
     ztc.installPackage('ilrt.formalworkflow')
 
-
 class BaseTestCase(ptc.PloneTestCase):
     """Base class for test cases.
     """
